<ul{% if tabs.css_id %} id="{{ tabs.css_id }}"{% endif %} class="nav nav-tabs{% if tabs.css_class %} {{ tabs.css_class }}{% endif %}">
    {{ links }}
</ul>
<div class="tab-content card-body">
    {{ content }}
</div>
