{% if form_show_errors and field.errors %}
    <div id="{{field.errors.field_id}}_error" class="invalid-feedback">
    {% for error in field.errors %}
        <p id="error_{{ forloop.counter }}_{{ field.auto_id }}"><strong>{{ error }}</strong></p>
    {% endfor %}
    </div>
{% endif %}
